@@ -1,6 +1,6 @@
-use super::common::ImmutableString;
+use super::common::{ImmutableString, Range};
 
-/// A JSON value.
+/// Different kinds of JSON values.
 #[derive(Debug, PartialEq, Clone)]
 pub enum Value {
     StringLit(StringLit),
@@ -11,19 +11,6 @@ pub enum Value {
     NullKeyword(NullKeyword),
 }
 
-/// Information about where the node appears in the text file.
-#[derive(Debug, PartialEq, Clone)]
-pub struct Range {
-    /// Start position of the node in the file text.
-    pub pos: usize,
-    /// End position of the node in the file text.
-    pub end: usize,
-    /// Line of the start position of the node in the file text.
-    pub start_line: usize,
-    /// Line of the end position of the node in the file text.
-    pub end_line: usize,
-}
-
 /// Node surrounded in double quotes (ex. `"my string"`).
 #[derive(Debug, PartialEq, Clone)]
 pub struct StringLit {
@@ -31,34 +18,34 @@ pub struct StringLit {
     pub value: ImmutableString,
 }
 
-/// Node that represents a number (ex. `123`, `99.99`, `-1.2e+2`).
+/// Represents a number (ex. `123`, `99.99`, `-1.2e+2`).
 #[derive(Debug, PartialEq, Clone)]
 pub struct NumberLit {
     pub range: Range,
     pub value: ImmutableString,
 }
 
-/// Node that represents a boolean (ex. `true` or `false`).
+/// Represents a boolean (ex. `true` or `false`).
 #[derive(Debug, PartialEq, Clone)]
 pub struct BooleanLit {
     pub range: Range,
     pub value: bool,
 }
 
-/// Node that represents the null keyword (ex. `null`).
+/// Represents the null keyword (ex. `null`).
 #[derive(Debug, PartialEq, Clone)]
 pub struct NullKeyword {
     pub range: Range,
 }
 
-/// Node that represents an object that may contain properties (ex. `{}`, `{ "prop": 4 }`).
+/// Represents an object that may contain properties (ex. `{}`, `{ "prop": 4 }`).
 #[derive(Debug, PartialEq, Clone)]
 pub struct Object {
     pub range: Range,
     pub properties: Vec<ObjectProp>,
 }
 
-/// Node that represents an object property (ex. `"prop": []`).
+/// Represents an object property (ex. `"prop": []`).
 #[derive(Debug, PartialEq, Clone)]
 pub struct ObjectProp {
     pub range: Range,
@@ -66,14 +53,14 @@ pub struct ObjectProp {
     pub value: Value,
 }
 
-/// Node that represents an array that may contain elements (ex. `[]` or `[5, 6]`).
+/// Represents an array that may contain elements (ex. `[]` or `[5, 6]`).
 #[derive(Debug, PartialEq, Clone)]
 pub struct Array {
     pub range: Range,
     pub elements: Vec<Value>,
 }
 
-/// Represents a comment.
+/// Different kinds of JSONC comments.
 #[derive(Debug, PartialEq, Clone)]
 pub enum Comment {
     Line(CommentLine),
